@@ -29,6 +29,7 @@ use uv_normalize::PackageName;
 use uv_pep440::Version;
 use uv_pep508::MarkerEnvironment;
 use uv_platform_tags::Platform;
+use uv_pypi_types::ProjectStatus;
 use uv_pypi_types::{
     PypiSimpleDetail, PypiSimpleIndex, PyxSimpleDetail, PyxSimpleIndex, ResolutionMetadata,
 };
@@ -643,6 +644,7 @@ impl RegistryClient {
                             data.files,
                             data.core_metadata,
                             package_name,
+                            data.project_status,
                             &url,
                         )
                     }
@@ -658,6 +660,7 @@ impl RegistryClient {
                             data.files,
                             data.core_metadata,
                             package_name,
+                            data.project_status,
                             &url,
                         )
                     }
@@ -670,7 +673,12 @@ impl RegistryClient {
                         let data: PypiSimpleDetail = serde_json::from_slice(bytes.as_ref())
                             .map_err(|err| Error::from_json_err(err, url.clone()))?;
 
-                        SimpleDetailMetadata::from_pypi_files(data.files, package_name, &url)
+                        SimpleDetailMetadata::from_pypi_files(
+                            data.files,
+                            package_name,
+                            data.project_status,
+                            &url,
+                        )
                     }
                     MediaType::PypiV1Html | MediaType::TextHtml => {
                         let text = response
@@ -1369,9 +1377,15 @@ impl SimpleIndexMetadata {
     }
 }
 
+/// Detail response for a Python package from a Simple API index.
+///
+/// Abstracts over both HTML and JSON index formats.
 #[derive(Default, Debug, rkyv::Archive, rkyv::Deserialize, rkyv::Serialize)]
 #[rkyv(derive(Debug))]
-pub struct SimpleDetailMetadata(Vec<SimpleDetailMetadatum>);
+pub struct SimpleDetailMetadata {
+    project_status: ProjectStatus,
+    versions: Vec<SimpleDetailMetadatum>,
+}
 
 #[derive(Debug, rkyv::Archive, rkyv::Deserialize, rkyv::Serialize)]
 #[rkyv(derive(Debug))]
@@ -1383,12 +1397,13 @@ pub struct SimpleDetailMetadatum {
 
 impl SimpleDetailMetadata {
     pub fn iter(&self) -> impl DoubleEndedIterator<Item = &SimpleDetailMetadatum> {
-        self.0.iter()
+        self.versions.iter()
     }
 
     fn from_pypi_files(
         files: Vec<uv_pypi_types::PypiFile>,
         package_name: &PackageName,
+        project_status: ProjectStatus,
         base: &Url,
     ) -> Self {
         let mut version_map: BTreeMap<Version, VersionFiles> = BTreeMap::default();
@@ -1423,8 +1438,8 @@ impl SimpleDetailMetadata {
             }
         }
 
-        Self(
-            version_map
+        Self {
+            versions: version_map
                 .into_iter()
                 .map(|(version, files)| SimpleDetailMetadatum {
                     version,
@@ -1432,13 +1447,15 @@ impl SimpleDetailMetadata {
                     metadata: None,
                 })
                 .collect(),
-        )
+            project_status,
+        }
     }
 
     fn from_pyx_files(
         files: Vec<uv_pypi_types::PyxFile>,
         mut core_metadata: FxHashMap<Version, uv_pypi_types::CoreMetadatum>,
         package_name: &PackageName,
+        project_status: ProjectStatus,
         base: &Url,
     ) -> Self {
         let mut version_map: BTreeMap<Version, VersionFiles> = BTreeMap::default();
@@ -1473,8 +1490,8 @@ impl SimpleDetailMetadata {
             }
         }
 
-        Self(
-            version_map
+        Self {
+            versions: version_map
                 .into_iter()
                 .map(|(version, files)| {
                     let metadata =
@@ -1495,7 +1512,8 @@ impl SimpleDetailMetadata {
                     }
                 })
                 .collect(),
-        )
+            project_status,
+        }
     }
 
     /// Read the [`SimpleDetailMetadata`] from an HTML index.
@@ -1505,13 +1523,18 @@ impl SimpleDetailMetadata {
         url: &DisplaySafeUrl,
     ) -> Result<Self, Error> {
         let SimpleDetailHTML {
-            project_status: _,
+            project_status,
             base,
             files,
         } = SimpleDetailHTML::parse(text, url)
             .map_err(|err| Error::from_html_err(err, url.clone()))?;
 
-        Ok(Self::from_pypi_files(files, package_name, base.as_url()))
+        Ok(Self::from_pypi_files(
+            files,
+            package_name,
+            project_status,
+            base.as_url(),
+        ))
     }
 }
 
@@ -1520,17 +1543,17 @@ impl IntoIterator for SimpleDetailMetadata {
     type IntoIter = std::vec::IntoIter<SimpleDetailMetadatum>;
 
     fn into_iter(self) -> Self::IntoIter {
-        self.0.into_iter()
+        self.versions.into_iter()
     }
 }
 
 impl ArchivedSimpleDetailMetadata {
     pub fn iter(&self) -> impl DoubleEndedIterator<Item = &rkyv::Archived<SimpleDetailMetadatum>> {
-        self.0.iter()
+        self.versions.iter()
     }
 
     pub fn datum(&self, i: usize) -> Option<&rkyv::Archived<SimpleDetailMetadatum>> {
-        self.0.get(i)
+        self.versions.get(i)
     }
 }
 
@@ -1835,6 +1858,7 @@ mod tests {
         let simple_metadata = SimpleDetailMetadata::from_pypi_files(
             data.files,
             &PackageName::from_str("pyflyby").unwrap(),
+            data.project_status,
             &base,
         );
         let versions: Vec<String> = simple_metadata
@@ -1844,6 +1868,205 @@ mod tests {
         assert_eq!(versions, ["1.7.8".to_string()]);
     }
 
+    /// Test for project statuses from PyPI's JSON detail response.
+    #[test]
+    fn project_status_pypi_json() {
+        // Minimized from https://pypi.org/simple/pepy/
+        let json = r#"
+        {
+          "alternate-locations": [],
+          "files": [
+            {
+              "core-metadata": false,
+              "data-dist-info-metadata": false,
+              "filename": "pepy-2.1.1.tar.gz",
+              "hashes": {
+                "sha256": "cec463c444b71d1664229121897b22df753dc91fabb2113d1c89992638c90829"
+              },
+              "provenance": null,
+              "requires-python": ">=3.7",
+              "size": 15399,
+              "upload-time": "2022-11-14T17:14:53.935145Z",
+              "url": "https://files.pythonhosted.org/packages/78/7e/123d89ce0e999e957e53f0b985f734565c93b9a698af53586fc2a1be0dbf/pepy-2.1.1.tar.gz",
+              "yanked": false
+            }
+          ],
+          "meta": {
+            "_last-serial": 15765070,
+            "api-version": "1.4"
+          },
+          "name": "pepy",
+          "project-status": {
+            "status": "archived"
+          },
+          "versions": [
+            "2.1.1"
+          ]
+        }
+        "#;
+
+        let data: PypiSimpleDetail = serde_json::from_str(json).unwrap();
+        let base = DisplaySafeUrl::parse("https://pypi.org/simple/pepy/").unwrap();
+        let simple_metadata = SimpleDetailMetadata::from_pypi_files(
+            data.files,
+            &PackageName::from_str("pepy").unwrap(),
+            data.project_status,
+            &base,
+        );
+
+        insta::assert_debug_snapshot!(simple_metadata, @r#"
+        SimpleDetailMetadata {
+            project_status: ProjectStatus {
+                status: Archived,
+                reason: None,
+            },
+            versions: [
+                SimpleDetailMetadatum {
+                    version: "2.1.1",
+                    files: VersionFiles {
+                        wheels: [],
+                        source_dists: [
+                            VersionSourceDist {
+                                name: SourceDistFilename {
+                                    name: PackageName(
+                                        "pepy",
+                                    ),
+                                    version: "2.1.1",
+                                    extension: TarGz,
+                                },
+                                file: File {
+                                    dist_info_metadata: false,
+                                    filename: "pepy-2.1.1.tar.gz",
+                                    hashes: HashDigests(
+                                        [
+                                            HashDigest {
+                                                algorithm: Sha256,
+                                                digest: "cec463c444b71d1664229121897b22df753dc91fabb2113d1c89992638c90829",
+                                            },
+                                        ],
+                                    ),
+                                    requires_python: Some(
+                                        VersionSpecifiers(
+                                            [
+                                                VersionSpecifier {
+                                                    operator: GreaterThanEqual,
+                                                    version: "3.7",
+                                                },
+                                            ],
+                                        ),
+                                    ),
+                                    size: Some(
+                                        15399,
+                                    ),
+                                    upload_time_utc_ms: Some(
+                                        1668446093935,
+                                    ),
+                                    url: AbsoluteUrl(
+                                        UrlString(
+                                            "https://files.pythonhosted.org/packages/78/7e/123d89ce0e999e957e53f0b985f734565c93b9a698af53586fc2a1be0dbf/pepy-2.1.1.tar.gz",
+                                        ),
+                                    ),
+                                    yanked: Some(
+                                        Bool(
+                                            false,
+                                        ),
+                                    ),
+                                    zstd: None,
+                                },
+                            },
+                        ],
+                    },
+                    metadata: None,
+                },
+            ],
+        }
+        "#);
+    }
+
+    /// Test for project statuses from PyPI's HTML detail response.
+    #[test]
+    fn project_status_pypi_html() {
+        // Minimized from https://pypi.org/simple/pepy/
+        let html = r#"
+        <!DOCTYPE html>
+        <html lang="en">
+          <head>
+            <meta name="pypi:repository-version" content="1.4">
+        <meta name="pypi:project-status" content="archived">    <title>Links for pepy</title>
+          </head>
+          <body>
+            <h1>Links for pepy</h1>
+        <a href="https://files.pythonhosted.org/packages/78/7e/123d89ce0e999e957e53f0b985f734565c93b9a698af53586fc2a1be0dbf/pepy-2.1.1.tar.gz#sha256=cec463c444b71d1664229121897b22df753dc91fabb2113d1c89992638c90829" data-requires-python="&gt;=3.7" >pepy-2.1.1.tar.gz</a><br />
+        </body>
+        </html>
+        <!--SERIAL 15765070-->
+        "#;
+
+        let base = DisplaySafeUrl::parse("https://pypi.org/simple/pepy/").unwrap();
+        let simple_metadata =
+            SimpleDetailMetadata::from_html(html, &PackageName::from_str("pepy").unwrap(), &base)
+                .unwrap();
+        insta::assert_debug_snapshot!(simple_metadata, @r#"
+        SimpleDetailMetadata {
+            project_status: ProjectStatus {
+                status: Archived,
+                reason: None,
+            },
+            versions: [
+                SimpleDetailMetadatum {
+                    version: "2.1.1",
+                    files: VersionFiles {
+                        wheels: [],
+                        source_dists: [
+                            VersionSourceDist {
+                                name: SourceDistFilename {
+                                    name: PackageName(
+                                        "pepy",
+                                    ),
+                                    version: "2.1.1",
+                                    extension: TarGz,
+                                },
+                                file: File {
+                                    dist_info_metadata: false,
+                                    filename: "pepy-2.1.1.tar.gz",
+                                    hashes: HashDigests(
+                                        [
+                                            HashDigest {
+                                                algorithm: Sha256,
+                                                digest: "cec463c444b71d1664229121897b22df753dc91fabb2113d1c89992638c90829",
+                                            },
+                                        ],
+                                    ),
+                                    requires_python: Some(
+                                        VersionSpecifiers(
+                                            [
+                                                VersionSpecifier {
+                                                    operator: GreaterThanEqual,
+                                                    version: "3.7",
+                                                },
+                                            ],
+                                        ),
+                                    ),
+                                    size: None,
+                                    upload_time_utc_ms: None,
+                                    url: AbsoluteUrl(
+                                        UrlString(
+                                            "https://files.pythonhosted.org/packages/78/7e/123d89ce0e999e957e53f0b985f734565c93b9a698af53586fc2a1be0dbf/pepy-2.1.1.tar.gz",
+                                        ),
+                                    ),
+                                    yanked: None,
+                                    zstd: None,
+                                },
+                            },
+                        ],
+                    },
+                    metadata: None,
+                },
+            ],
+        }
+        "#);
+    }
+
     /// Test for AWS Code Artifact registry
     ///
     /// See: <https://github.com/astral-sh/uv/issues/1388>
