@@ -15,7 +15,7 @@ fn python_list() {
         .with_filtered_python_keys()
         .with_collapsed_whitespace();
 
-    uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, ""), @r"
+    uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, ""), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -24,7 +24,7 @@ fn python_list() {
     ");
 
     // We show all interpreters
-    uv_snapshot!(context.filters(), context.python_list(), @r"
+    uv_snapshot!(context.filters(), context.python_list(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -35,7 +35,7 @@ fn python_list() {
     ");
 
     // Request Python 3.12
-    uv_snapshot!(context.filters(), context.python_list().arg("3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -45,7 +45,7 @@ fn python_list() {
     ");
 
     // Request Python 3.11
-    uv_snapshot!(context.filters(), context.python_list().arg("3.11"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -55,7 +55,7 @@ fn python_list() {
     ");
 
     // Request CPython
-    uv_snapshot!(context.filters(), context.python_list().arg("cpython"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("cpython"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -66,7 +66,7 @@ fn python_list() {
     ");
 
     // Request CPython 3.12
-    uv_snapshot!(context.filters(), context.python_list().arg("cpython@3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("cpython@3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -76,7 +76,7 @@ fn python_list() {
     ");
 
     // Request CPython 3.12 via partial key syntax
-    uv_snapshot!(context.filters(), context.python_list().arg("cpython-3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("cpython-3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -89,7 +89,7 @@ fn python_list() {
     let os = Os::from_env();
     let arch = Arch::from_env();
 
-    uv_snapshot!(context.filters(), context.python_list().arg(format!("cpython-3.12-{os}-{arch}")), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg(format!("cpython-3.12-{os}-{arch}")), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -99,7 +99,7 @@ fn python_list() {
     ");
 
     // Request PyPy (which should be missing)
-    uv_snapshot!(context.filters(), context.python_list().arg("pypy"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("pypy"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -110,7 +110,7 @@ fn python_list() {
     // Swap the order of the Python versions
     context.python_versions.reverse();
 
-    uv_snapshot!(context.filters(), context.python_list(), @r"
+    uv_snapshot!(context.filters(), context.python_list(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -121,7 +121,7 @@ fn python_list() {
     ");
 
     // Request Python 3.11
-    uv_snapshot!(context.filters(), context.python_list().arg("3.11"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -139,17 +139,17 @@ fn python_list_pin() {
         .with_collapsed_whitespace();
 
     // Pin to a version
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `3.12`
 
     ----- stderr -----
-    "###);
+    ");
 
     // The pin should not affect the listing
-    uv_snapshot!(context.filters(), context.python_list(), @r"
+    uv_snapshot!(context.filters(), context.python_list(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -160,7 +160,7 @@ fn python_list_pin() {
     ");
 
     // So `--no-config` has no effect
-    uv_snapshot!(context.filters(), context.python_list().arg("--no-config"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("--no-config"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -182,16 +182,16 @@ fn python_list_venv() {
         .with_collapsed_whitespace();
 
     // Create a virtual environment
-    uv_snapshot!(context.filters(), context.venv().arg("--python").arg("3.12").arg("-q"), @r###"
+    uv_snapshot!(context.filters(), context.venv().arg("--python").arg("3.12").arg("-q"), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-    "###);
+    ");
 
     // We should not display the virtual environment
-    uv_snapshot!(context.filters(), context.python_list(), @r"
+    uv_snapshot!(context.filters(), context.python_list(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -201,8 +201,8 @@ fn python_list_venv() {
     ----- stderr -----
     ");
 
-    // Same if the `VIRTUAL_ENV` is not set (the test context includes it by default)
-    uv_snapshot!(context.filters(), context.python_list().env_remove(EnvVars::VIRTUAL_ENV), @r"
+    // Same if the `VIRTUAL_ENV` is not set
+    uv_snapshot!(context.filters(), context.python_list(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -221,7 +221,7 @@ fn python_list_unsupported_version() {
         .with_filtered_python_keys();
 
     // Request a low version
-    uv_snapshot!(context.filters(), context.python_list().arg("3.6"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.6"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -231,7 +231,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request a low version with a patch
-    uv_snapshot!(context.filters(), context.python_list().arg("3.6.9"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.6.9"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -241,7 +241,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request a really low version
-    uv_snapshot!(context.filters(), context.python_list().arg("2.6"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("2.6"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -251,7 +251,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request a really low version with a patch
-    uv_snapshot!(context.filters(), context.python_list().arg("2.6.8"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("2.6.8"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -261,7 +261,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request a future version
-    uv_snapshot!(context.filters(), context.python_list().arg("4.2"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("4.2"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -270,7 +270,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request a low version with a range
-    uv_snapshot!(context.filters(), context.python_list().arg("<3.0"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("<3.0"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -279,7 +279,7 @@ fn python_list_unsupported_version() {
     ");
 
     // Request free-threaded Python on unsupported version
-    uv_snapshot!(context.filters(), context.python_list().arg("3.12t"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.12t"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -303,7 +303,7 @@ fn python_list_duplicate_path_entries() {
     )
     .unwrap();
 
-    uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @r"
+    uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -325,15 +325,15 @@ fn python_list_duplicate_path_entries() {
         ))
         .unwrap();
 
-        uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @r"
-            success: true
-            exit_code: 0
-            ----- stdout -----
-            cpython-3.12.[X]-[PLATFORM] [PYTHON-3.12]
-            cpython-3.11.[X]-[PLATFORM] [PYTHON-3.11]
+        uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @"
+        success: true
+        exit_code: 0
+        ----- stdout -----
+        cpython-3.12.[X]-[PLATFORM] [PYTHON-3.12]
+        cpython-3.11.[X]-[PLATFORM] [PYTHON-3.11]
 
-            ----- stderr -----
-            ");
+        ----- stderr -----
+        ");
 
         // Reverse the order so the symlinks are first
         let path = std::env::join_paths(
@@ -346,7 +346,7 @@ fn python_list_duplicate_path_entries() {
         )
         .unwrap();
 
-        uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @r"
+        uv_snapshot!(context.filters(), context.python_list().env(EnvVars::UV_TEST_PYTHON_PATH, &path), @"
         success: true
         exit_code: 0
         ----- stdout -----
@@ -366,7 +366,7 @@ fn python_list_downloads() {
     // Instead, we choose a Python version where our available distributions are stable
 
     // Test the default display, which requires reverting the test context disabling Python downloads
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -378,7 +378,7 @@ fn python_list_downloads() {
     ");
 
     // Show patch versions
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--all-versions").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--all-versions").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -425,7 +425,7 @@ fn python_list_downloads_installed() {
     // Instead, we choose a Python version where our available distributions are stable
 
     // First, the download is shown as available
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -440,7 +440,7 @@ fn python_list_downloads_installed() {
     // the URL
 
     // But not if `--only-installed` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-installed").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-installed").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -452,7 +452,7 @@ fn python_list_downloads_installed() {
     context.python_install().arg("3.10").assert().success();
 
     // Then, it should be listed as installed instead of available
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -464,7 +464,7 @@ fn python_list_downloads_installed() {
     ");
 
     // But, the display should be reverted if `--only-downloads` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-downloads").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-downloads").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -476,7 +476,7 @@ fn python_list_downloads_installed() {
     ");
 
     // And should not be shown if `--no-managed-python` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--no-managed-python").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--no-managed-python").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -548,7 +548,7 @@ async fn python_list_remote_python_downloads_json_url() -> Result<()> {
         .arg("--all-platforms")
         .arg("--all-arches")
         .arg("--show-urls")
-        .arg("--python-downloads-json-url").arg(server.uri()), @r"
+        .arg("--python-downloads-json-url").arg(server.uri()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -562,7 +562,7 @@ async fn python_list_remote_python_downloads_json_url() -> Result<()> {
     uv_snapshot!(context.filters(), context
         .python_list()
         .env_remove(EnvVars::UV_PYTHON_DOWNLOADS)
-        .arg("--python-downloads-json-url").arg(format!("{}/404", server.uri())), @r"
+        .arg("--python-downloads-json-url").arg(format!("{}/404", server.uri())), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -571,14 +571,13 @@ async fn python_list_remote_python_downloads_json_url() -> Result<()> {
     error: Error while fetching remote python downloads json from 'http://[LOCALHOST]/404'
       Caused by: Failed to download http://[LOCALHOST]/404
       Caused by: HTTP status client error (404 Not Found) for url (http://[LOCALHOST]/404)
-
     ");
 
     // test invalid json
     uv_snapshot!(context.filters(), context
         .python_list()
         .env_remove(EnvVars::UV_PYTHON_DOWNLOADS)
-        .arg("--python-downloads-json-url").arg(format!("{}/invalid", server.uri())), @r"
+        .arg("--python-downloads-json-url").arg(format!("{}/invalid", server.uri())), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -586,7 +585,6 @@ async fn python_list_remote_python_downloads_json_url() -> Result<()> {
     ----- stderr -----
     error: Unable to parse the JSON Python download list at http://[LOCALHOST]/invalid
       Caused by: EOF while parsing an object at line 1 column 1
-
     ");
 
     Ok(())
@@ -629,7 +627,7 @@ fn python_list_with_mirrors() {
         .arg("cpython@3.10.19")
         .arg("--show-urls")
         .env(EnvVars::UV_PYTHON_INSTALL_MIRROR, "https://mirror.example.com")
-        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -643,7 +641,7 @@ fn python_list_with_mirrors() {
         .arg("pypy@3.10")
         .arg("--show-urls")
         .env(EnvVars::UV_PYPY_INSTALL_MIRROR, "https://pypy-mirror.example.com")
-        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -658,7 +656,7 @@ fn python_list_with_mirrors() {
         .arg("--show-urls")
         .env(EnvVars::UV_PYTHON_INSTALL_MIRROR, "https://python-mirror.example.com")
         .env(EnvVars::UV_PYPY_INSTALL_MIRROR, "https://pypy-mirror.example.com")
-        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -673,7 +671,7 @@ fn python_list_with_mirrors() {
     uv_snapshot!(context.filters(), context.python_list()
         .arg("3.10")
         .arg("--show-urls")
-        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
+        .env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @"
     success: true
     exit_code: 0
     ----- stdout -----
