@@ -12,14 +12,14 @@ fn tool_dir() {
 
     uv_snapshot!(context.filters(), context.tool_dir()
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
     [TEMP_DIR]/tools
 
     ----- stderr -----
-    "###);
+    ");
 }
 
 #[test]
@@ -30,12 +30,12 @@ fn tool_dir_bin() {
 
     uv_snapshot!(context.filters(), context.tool_dir().arg("--bin")
     .env(EnvVars::UV_TOOL_DIR, tool_dir.as_os_str())
-    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @r###"
+    .env(EnvVars::XDG_BIN_HOME, bin_dir.as_os_str()), @"
     success: true
     exit_code: 0
     ----- stdout -----
     [TEMP_DIR]/bin
 
     ----- stderr -----
-    "###);
+    ");
 }
