@@ -8,7 +8,7 @@ fn packse_add_remove_one_package() {
     let context = TestContext::new("3.12");
     context.copy_ecosystem_project("packse");
 
-    uv_snapshot!(context.filters(), context.lock(), @r"
+    uv_snapshot!(context.filters(), context.lock(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -207,7 +207,7 @@ fn packse_add_remove_one_package() {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(diff, @r###""###);
+        assert_snapshot!(diff, @"");
     });
 }
 
@@ -216,7 +216,7 @@ fn packse_add_remove_existing_package_noop() {
     let context = TestContext::new("3.12");
     context.copy_ecosystem_project("packse");
 
-    uv_snapshot!(context.filters(), context.lock(), @r"
+    uv_snapshot!(context.filters(), context.lock(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -252,7 +252,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
     let context = TestContext::new("3.12");
     context.copy_ecosystem_project("packse");
 
-    uv_snapshot!(context.filters(), context.lock(), @r"
+    uv_snapshot!(context.filters(), context.lock(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -277,7 +277,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(diff, @r###"
+        assert_snapshot!(diff, @r#"
         --- old
         +++ new
         @@ -306,20 +306,21 @@
@@ -324,7 +324,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
              { name = "psutil", specifier = ">=5.9.7" },
              { name = "pytest", specifier = ">=7.4.3" },
              { name = "syrupy", specifier = ">=4.6.0" },
-        "###);
+        "#);
     });
 
     let diff = context.diff_lock(|context| {
@@ -335,7 +335,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(diff, @r###"
+        assert_snapshot!(diff, @r#"
         --- old
         +++ new
         @@ -306,21 +306,20 @@
@@ -382,7 +382,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
              { name = "psutil", specifier = ">=5.9.7" },
              { name = "pytest", specifier = ">=7.4.3" },
              { name = "syrupy", specifier = ">=4.6.0" },
-        "###);
+        "#);
     });
 
     // Back to where we started.
@@ -391,7 +391,7 @@ fn packse_promote_transitive_to_direct_then_remove() {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(diff, @r###""###);
+        assert_snapshot!(diff, @"");
     });
 }
 
@@ -410,14 +410,14 @@ fn jax_instability() -> Result<()> {
         "#,
     )?;
 
-    uv_snapshot!(context.filters(), context.lock(), @r###"
+    uv_snapshot!(context.filters(), context.lock(), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
     Resolved 8 packages in [TIME]
-    "###);
+    ");
 
     let lock = context.read("uv.lock");
     insta::with_settings!({
